@@ -32,13 +32,13 @@ class LeapLoaderParallelizedBase(ABC):
         self._generate_inputs_thread: Optional[Thread] = None
         self._should_stop_thread = False
 
-    def _calculate_n_workers_by_hardware(self) -> int:
+    def _calculate_n_workers_bpyproject.tomly_hardware(self) -> int:
         p = psutil.Process(self.processes[0].pid)
         memory_usage_in_bytes = p.memory_info().rss
         total_memory_in_bytes = psutil.virtual_memory().total
 
         n_workers = min(int(multiprocessing.cpu_count()),
-                        int(total_memory_in_bytes * 0.7 / memory_usage_in_bytes))
+                        int(total_memory_in_bytes * 0.5 / memory_usage_in_bytes))
         n_workers = max(n_workers, 1)
         return n_workers
 
